@@ -1,6 +1,6 @@
 import csv
 
-from .csv_parser import Parser as BaseParser
+from convertextract.parsers.csv_parser import Parser as BaseParser
 
 class Parser(BaseParser):
     """Extract text from pipe separated values files (.psv).
